@@ -69,11 +69,16 @@ our @gend_pods = ();
 =item HASH = Glib::MakeHelper->do_pod_files (@xs_files)
 
 Scan the I<@xs_files> and return a hash describing the pod files that will
-be created.  This is in the format wanted by WriteMakefile().
+be created.  This is in the format wanted by WriteMakefile(). If @ARGV contains
+the string --disable-apidoc an empty list will be returned and thus no apidoc 
+pod will be generated speeding up the build process.
 
 =cut
 sub do_pod_files
 {
+	return () if (grep /disable[-_]apidoc/i, @ARGV);
+	print STDERR "Including ApiDoc pod.\n";
+
 	shift; # package name
 
 	# try to get it from pwd first, then fall back to installed
@@ -133,6 +138,10 @@ Use this in your MY::postamble to enable autogeneration of POD.
 This updates dependencies with the list of pod names generated by an earlier
 run of C<do_pod_files>.
 
+There is a special Makefile variable POD_DEPENDS that should be set to the
+list of files that need to be created before the doc.pl step is run, include
+files.
+
 =cut
 sub postamble_docs
 {
@@ -140,17 +149,14 @@ sub postamble_docs
 	my @xs_files = @_;
 "
 # documentation stuff
-build/doc.pl :: Makefile @xs_files 
+build/doc.pl :: Makefile @xs_files
 	$^X -I \$(INST_LIB) -I \$(INST_ARCHLIB) -MGlib::ParseXSDoc \\
 		-e 'xsdocparse (".join(", ",map {"\"$_\""} @xs_files).")' > \$@
 
-build/xsapi.pod :: build/doc.pl apidoc.pl xsapi.pod.head xsapi.pod.foot
-	$^X apidoc.pl xsapi.pod.head xsapi.pod.foot build/doc.pl > \$@
-
 # passing all of these files through the single podindex file, which is 
 # created at the same time, prevents problems with -j4 where xsdoc2pod would 
 # have multiple instances
-@gend_pods :: build/podindex
+@gend_pods :: build/podindex \$(POD_DEPENDS)
 
 build/podindex :: Makefile build/doc.pl \$(INST_LIB)/\$(FULLEXT).pm \$(INST_DYNAMIC)
 	$^X -I \$(INST_LIB) -I \$(INST_ARCHLIB) -MGlib::GenPod -M\$(NAME) \\
